@@ -17,7 +17,7 @@
 #' offering <- '00003'
 #' property <- '00060'
 #' obs_url <- constructNWISURL(siteNumber,property,startDate,endDate,'dv')
-#' \dontrun{
+#' \donttest{
 #' rawData <- getWebServiceData(obs_url)
 #' }
 getWebServiceData <- function(obs_url, ...){
@@ -33,7 +33,6 @@ getWebServiceData <- function(obs_url, ...){
     message("For: ", obs_url,"\n")
     httr::stop_for_status(returnedList)
   } else {
-    
     headerInfo <- httr::headers(returnedList)
 
     if(headerInfo$`content-type` %in% c("text/tab-separated-values;charset=UTF-8")){
@@ -48,8 +47,6 @@ getWebServiceData <- function(obs_url, ...){
       txt <- readBin(returnedList$content, character())
       message(txt)
       return(txt)
-      
-
     } else {
       returnedDoc <- httr::content(returnedList,encoding = "UTF-8")
       if(grepl("No sites/data found using the selection criteria specified", returnedDoc)){
@@ -80,7 +77,14 @@ default_ua <- function() {
     httr = as.character(packageVersion("httr")),
     dataRetrieval = as.character(packageVersion("dataRetrieval"))
   )
-  paste0(names(versions), "/", versions, collapse = " ")
+  
+  ua <- paste0(names(versions), "/", versions, collapse = " ")
+  
+  if("UA.dataRetrieval" %in% names(options)){
+    ua <- paste0(ua, "/", options()[["UA.dataRetrieval"]])
+  }
+    
+  return(ua)
 }
 
 #' getting header information from a WQP query
@@ -107,8 +111,12 @@ retryGetOrPost <- function(obs_url, ...) {
     split <- strsplit(obs_url, "?", fixed=TRUE)
     obs_url <- split[[1]][1]
     query <- split[[1]][2]
-    resp <- httr::RETRY("POST", obs_url, ..., body = query,
-                        httr::content_type("application/x-www-form-urlencoded"), httr::user_agent(default_ua()))
+
+    resp <- httr::RETRY("POST", obs_url, ...,
+                        body = query,
+                        httr::content_type("application/x-www-form-urlencoded"),
+                        httr::user_agent(default_ua())) 
+
   }
   return(resp)
 }
\ No newline at end of file
