@@ -1,10 +1,17 @@
 #' Site Data Import from Water Quality Portal
 #'
 #' Returns a list of sites from the Water Quality Portal web service. This function gets the data from: \url{https://www.waterqualitydata.us}.
-#' Arguments to the function should be based on \url{https://www.waterqualitydata.us/webservices_documentation}
+#' Arguments to the function should be based on \url{https://www.waterqualitydata.us/webservices_documentation}. The return from 
+#' this function returns the basic metadata on WQP sites. It is
+#' generally faster than the \code{\link{whatWQPdata}} function, but does
+#' not return information on what data was collected at the site.
+#'
+#' The \code{readWQPsummary} function has 
 #'
 #' @param \dots see \url{https://www.waterqualitydata.us/webservices_documentation} for a complete list of options. A list of arguments can also be supplied.
 #' @keywords data import WQP web service
+#' @rdname wqpSpecials
+#' @name whatWQPsites
 #' @return A data frame with at least the following columns:
 #' \tabular{lll}{ 
 #' Name \tab Type \tab Description \cr
@@ -48,14 +55,16 @@
 #' * element is only in NWIS
 #' 
 #' @export
+#' @seealso whatNWISdata
 #' @import utils
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' site1 <- whatWQPsites(siteid="USGS-01594440")
 #' 
 #' type <- "Stream"
-#' sites <- whatWQPsites(countycode="US:55:025",siteType=type)
-#' lakeSites <- whatWQPsites(siteType = "Lake, Reservoir, Impoundment", statecode = "US:55")
+#' sites <- whatWQPsites(countycode="US:55:025",
+#'                       characteristicName = "Phosphorus",
+#'                       siteType=type)
 #' }
 whatWQPsites <- function(...){
 
@@ -69,11 +78,10 @@ whatWQPsites <- function(...){
     
   urlCall <- paste(paste(names(values),values,sep="="),collapse="&")
   
-  
   baseURL <- drURL("wqpStation")
   urlCall <- paste0(baseURL,
                urlCall,
-               "&mimeType=tsv&sorted=no")
+               "&mimeType=tsv")
 
   retval <- importWQP(urlCall, zip=values["zip"] == "yes")
   
@@ -81,6 +89,50 @@ whatWQPsites <- function(...){
   attr(retval, "url") <- urlCall
   
   return(retval)
-  
-
 }
+
+
+#' @name readWQPsummary
+#' @rdname wqpSpecials
+#' @export
+#' @examples
+#' \donttest{
+#' site1 <- readWQPsummary(siteid="USGS-07144100",
+#'                         summaryYears=5,
+#'                         dataProfile="periodOfRecord")
+#' # Pretty slow:
+#' #state1 <- readWQPsummary(statecode="NJ",
+#' #                          dataProfile="periodOfRecord")
+#' }
+readWQPsummary <- function(...){
+  
+  values <- readWQPdots(...)
+  
+  if("tz" %in% names(values)){
+    values <- values[!(names(values) %in% "tz")]
+  }
+  
+  values <- sapply(values, function(x) URLencode(x, reserved = TRUE))
+  
+  urlCall <- paste(paste(names(values),values,sep="="),collapse="&")
+  
+  baseURL <- drURL("wqpSiteSummary")
+  urlCall <- paste0(baseURL,
+                    urlCall,
+                    "&mimeType=csv")
+  
+  withCallingHandlers({
+    retval <- importWQP(urlCall, zip=values["zip"] == "yes", csv = TRUE)
+  }, warning=function(w) {
+    if (any( grepl( "Number of rows returned not matched in header", w)))
+      invokeRestart("muffleWarning")
+  })
+  attr(retval, "queryTime") <- Sys.time()
+  attr(retval, "url") <- urlCall
+  
+  return(retval)
+  
+  
+}
+
+
